.. highlight:: shell

============
Installation
============


Stable release
--------------

To install OpenTISim, run this command in your terminal:

.. code-block:: bash

    # Use pip to install OpenTISim
    pip install opentisim

This is the preferred method to install OpenTISim, as it will always install the most recent stable release.

If you do not `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


From sources
------------

The sources for OpenTISim can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: bash

    # Use git to clone OpenTISim
    git clone git://github.com/TUDelft-CITG/OpenTISim


Or download the `tarball`_:

.. code-block:: bash

    # Use curl to obtain the tarball
    curl  -OL https://github.com/TUDelft-CITG/OpenTISim/tarball/master


Once you have a copy of the source, you can install it with:

.. code-block:: bash

    # Use python to install
    python setup.py install


.. _Github repo: https://github.com/TUDelft-CITG/OpenTNSim
.. _tarball: https://github.com/TUDelft-CITG/OpenTNSim/tarball/master
